@@ -62,7 +62,7 @@ public:
     ~MainWindow();
 
     void setActiveChat(QString jid);
-    bool hasChatOpen(Contact& c);
+    bool hasChatOpen(Contact *c);
     void statusChanged(FMessage message);
 
 protected:
@@ -91,8 +91,8 @@ public slots:
     void lockModeChanged(QString lockMode);
     void available(QString jid, bool online);
     void available(QString jid, qint64 lastSeen);
-    void composing(QString jid, QString media);
-    void paused(QString jid);
+    void composing(QString jid, QString participant, QString media);
+    void paused(QString jid, QString participant);
     void showDonate();
     void groupLeft(QString jid);
     void requestSync();
@@ -106,6 +106,7 @@ public slots:
     void requestPhotoUpdate(QString jid, QString photoId, bool largeFormat);
     void requestContactStatus(QString jid);
     void sendVoiceNotePlayed(FMessage message);
+    void sendMessageRead(FMessage message);
     void showStatusWindow();
     void photoReceived(Contact& c, QImage photo, QString photoId);
     void viewContact(Contact *c);
@@ -121,11 +122,19 @@ public slots:
     void blockOrUnblockContact(QString jid, bool blocked);
     void refreshPrivacyList();
     void requestUpdateLastDir(int waType, QString dir);
+    void forwardMessage(FMessage message);
 
 private:
     Ui::MainWindow *ui;
+
+    // This is the list of the lastContactList contacts that have an
+    // chat window open
     QMap<QString,ChatWindow *> chatWindowList;
+
+    // This is the list of the contacts with ongoing conversations
+    // aka the contact list in the MainWindow
     QMap<QString,ChatDisplayItem *> lastContactsList;
+
     ContactRoster *roster;
     bool isScreenLocked;
     NotifyObject *notifyObject;
@@ -172,7 +181,9 @@ signals:
     void requestBlockOrUnblockContact(QString jid, bool blocked);
     void privacyListRefreshed();
     void voiceNotePlayed(FMessage message);
+    void messageRead(FMessage message);
     void updateLastDir(int waType, QString dir);
+
 };
 
 #endif // MAINWINDOW_H
